@@ -21,7 +21,7 @@ required_settings = [
 for setting in required_settings:
     if not hasattr(settings, setting):
         raise ImproperlyConfigured(
-            "You must define {settings} in settings to use SquareletAuth"
+            f"You must define {setting} in settings to use SquareletAuth"
         )
 
 SOCIAL_AUTH_SQUARELET_KEY = settings.SOCIAL_AUTH_SQUARELET_KEY
